.. include:: /_includes/wip_prolog.rst


:mod:`stix.exploit_target` Module
==================================

.. module:: stix.exploit_target

Overview
--------
The :mod:`stix.exploit_target` module implements ``ExploitTarget``.
This denotes the specific vulnerability, weakness, or software configuration that creates a security risk.


Documentation Resources
~~~~~~~~~~~~~~~~~~~~~~~

* `ExploitTarget Data Model <https://stixproject.github.io/data-model/1.1.1/et/ExploitTargetType/>`_
* `ExploitTarget Idioms <https://stixproject.github.io/documentation/idioms/cve/>`_

Classes
-------

.. autoclass:: ExploitTarget
	:show-inheritance:
	:members:

.. autoclass:: PotentialCOAs
	:show-inheritance:
	:members:

.. autoclass:: RelatedExploitTargets
	:show-inheritance:
	:members:
